from google.appengine.api import users
from google.appengine.api import mail
from django.conf import settings
from django.contrib.auth.models import AnonymousUser

class GAEUser(object):
    def __init__(self, gae_user):
        self.gae_user = gae_user

    @property
    def username(self):
        if self.gae_user:
            return self.gae_user.nickname()

    @property
    def email(self):
        if self.gae_user:
            return self.gae_user.email()
    
    def __str__(self):
        return self.username

    def get_absolute_url(self):
        return "/%s/" % self.username

    def is_anonymous(self):
        return self.gae_user is None
    
    def is_authenticated(self):
        return self.gae_user is not None

    def get_full_name(self):
        return self.username

    def set_password(self, raw_password):
        # Do Nothing
        pass

    def check_password(self, raw_password):
        return True

    def get_group_permissions(self):
        return []
    
    def get_all_permissions(self):
        return []

    def has_perm(self, perm):
        return False

    def has_perms(self, perm_list):
        return False

    def has_module_perms(self, app_label):
        return False

    def get_and_delete_messages(self):
        return []

    def email_user(self, subject, message, from_email=None):
        mail.send_mail(sender=settings.DEFAULT_FROM_EMAIL,
                       to=self.email,
                       subject=subject,
                       body=message)

    def get_profile(self):
        raise SiteProfileNotAvailable
    
    def __getattr__(self, name):
        return None

class AuthenticationMiddleware(object):
    def process_request(self, request):
        """Puts the Google user object in the request object"""
        user = users.get_current_user()
        if user:
            request.__class__.user = GAEUser(user)
        else:
            request.__class__.user = AnonymousUser()            

        return None
