from django.http import HttpResponse, HttpResponseRedirect
from google.appengine.ext.webapp import template
from google.appengine.ext import db
from models import Message
from google.appengine.api import users
from templatefilters import unsafe_google_nickname
from django.template.defaultfilters import striptags

def require_login(func):
    def inner(request, *args, **kwargs):
        user = users.get_current_user()        
        if user:
            return func(request, *args, **kwargs)
        else:
            return HttpResponseRedirect(users.create_login_url(request.path))
    return inner

@require_login
def post(request):
    user = users.get_current_user()
    try:
        # Strip the tags from the content
        content = striptags(request.POST['content']).strip()
        if content:
            message = Message(author=user,
                              content=content,)
            message.put()
    except IndexError:
        pass

    return HttpResponseRedirect("/home/")        

                          
def user_page(request, nickname=None):
    query = Message.all()
    if nickname:
        email = unsafe_google_nickname(nickname)
        author = users.User(email=email)
        is_profile = False
    else:
        author = users.get_current_user()
        is_profile = True

    query.filter("author", author)
    message_list = query.order("-date").fetch(50)
    if is_profile:
        t = template.load("templates/profile.html")
    else:
        t = template.load("templates/user.html")

    return HttpResponse(t.render(template.Context({
                    'user': request.user,
                    'author': author,
                    'message_list': message_list,
                    })))

@require_login
def home(request):
    return user_page(request)

def index(request):
    query = Message.all()
    message_list = query.order("-date").fetch(50)
    t = template.load("templates/index.html")

    return HttpResponse(t.render(template.Context(
                {
                    'user': request.user,
                    'message_list': message_list
                    })))



def message_detail(request, key):
    message = Message.get(key)
    t = template.load("templates/message_detail.html")
    return HttpResponse(t.render(template.Context(
                {
                    'user': request.user,
                    'author': message.author,
                    'message': message
                    })))


def logout(request):
    return HttpResponseRedirect(users.create_logout_url("/"))

def login(request):
    return HttpResponseRedirect(users.create_login_url("/home/"))
